@@ -35,6 +35,20 @@ class Int(Field):
         return int(data[0])
 
 
+class IntHL(Field):
+    # Interger represented by high+low bytes
+    # https://stackoverflow.com/a/6090641/450103
+    parse_len = 2
+    range = None
+
+    def pack(self, value):
+        super().pack(self, value)  # validate range
+        return [(value >> 8) & 0xFF, value & 0xFF]
+
+    def parse(self, data):
+        return data[1] | (data[0] << 8)
+
+
 class Bool(Int):
     range = range(2)
 
@@ -86,12 +100,17 @@ class Time12H(Field):
 
 
 class Time(Field):
-    parse_len = 2
+    def __init__(self, name=None, seconds=False):
+        self.seconds = seconds
+        self.parse_len = 3 if seconds else 2
+        super().__init__(name)
 
     def parse(self, data):
-        return time(data[0], data[1])
+        return time(data[0], data[1], data[3] if self.seconds else 0)
 
     def pack(self, data):
+        if self.seconds:
+            return (data.hour, data.minute, data.second)
         return (data.hour, data.minute)
 
 
